@@ -10,7 +10,7 @@
  **                  MicroSoft Window and MSW32 means the 32 bit worlds
  **                  of MicroSoft Window. Therefore you want the environment
  **                  to be MicroSoft Window and in the 32 bit world -
- **                  __MSW__ and __MSW32__ must be uncommented out.
+ **                  _WIN32 must be defined by your compiler.
  **                  11/30/94 MCD Incorporated comments received for more
  **                  readability and the missing typedef for FLOAT.
  **                  12/1/94 MCD Added PFVOID typedef
@@ -48,7 +48,7 @@
 /******************************************************************************
  **                                IMPORTANT!!!                                                                                                                 **
  **                                                                                                                                                                              **
- ** Defines either __MSW__, __MSW32__, __MAC__, __UNIX__, __OS2__, __PM__ to
+ ** Defines either _WIN32, __MAC__, __UNIX__, __OS2__, __PM__ to
  ** use the specified definitions indicated below in the preprocessor settings.                                                        **
  **                                                                                                                                                                              **
  ** Also define either  __FarProc__ or  __FarData__  and __MOTO__ to use the
@@ -60,23 +60,10 @@
  ******************************************************************************/
 
 #include "platform.h"
-/* __MSW32__ */
-#ifdef __MSW32__
+/* _WIN32 */
+#ifdef _WIN32
 #include <windows.h>
 #include <winbase.h>             // winbase.h contains windows.h
-
-#define DLLIMPORT __declspec( dllimport)
-#define DLLEXPORT __declspec( dllexport)
-
-#else
-/********************************************************/
-/* __MSW__ */
-#ifdef __MSW__
-#include <windows.h>             // provides standard definitions (like HANDLE)
-
-#define DLLIMPORT __import
-#define DLLEXPORT __export
-#endif
 #endif
 
 /********************************************************/
@@ -85,17 +72,12 @@
 #include <Types.h>
 /*----------------------------*/
 /*----------------------------*/
-#define DLLIMPORT
-#define DLLEXPORT
-
 #endif
 /********************************************************/
 #if defined(__UNIX__) || defined( __DOS__ ) || defined(__OS2__) || defined(__PM__)
 /*----------------------------*/
 /* FarProc and FarData */
 /*----------------------------*/
-#define DLLIMPORT
-#define DLLEXPORT
 /*----------------------------*/
 #endif
 /*****************************************************************************
@@ -143,22 +125,13 @@ typedef unsigned char BOOL8;
 
 #define MIN_INT8  0x80
 #define MIN_INT16 0x8000
-#define MIN_INT32 0x80000000
+#define MIN_INT32 static_cast<int>(0x80000000)
 #define MIN_UINT8 0x00
 #define MIN_UINT16  0x0000
 #define MIN_UINT32  0x00000000
 #define MIN_FLOAT32 ((float)1.17549435e-38)
 
 // Defines
-
-#ifndef OKAY
-#define OKAY            0
-#endif
-
-#ifndef HPERR
-#define HPERR           -1
-#endif
-
 #ifndef TRUE
 #define TRUE            1
 #endif
@@ -167,10 +140,6 @@ typedef unsigned char BOOL8;
 #define FALSE           0
 #endif
 
-#ifndef NULL
-#define NULL            0L
-#endif
-
 // Return true if x is within tolerance of y
 template<class T> bool NearlyEqual(T x, T y, T tolerance) {
   T diff = x - y;
